@@ -4,7 +4,7 @@ options(warn = 1)
 options(pager = "console")
 library('FrF2.catlg128')
 
-assign(".oldSearch", search(), pos = 'CheckExEnv')
+base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
 cleanEx()
 nameEx("Catalogues")
 ### * Catalogues
@@ -38,7 +38,7 @@ catlg128.8to15[1:5]
 
 ### * <FOOTER>
 ###
-cat("Time elapsed: ", proc.time() - get("ptime", pos = 'CheckExEnv'),"\n")
+base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
 grDevices::dev.off()
 ###
 ### Local variables: ***
